import React from 'react'
import styled from '@emotion/styled/macro'
import { UseFormReturn } from 'react-hook-form'

interface InputProps
  extends Partial<React.InputHTMLAttributes<HTMLInputElement>>,
    Partial<UseFormReturn> {
  name: string
  errors?: any
  type?: 'text' | 'email' | 'number'
}

export const StyledInput = styled.input`
  width: 50%;
  border: 1px solid;
  border-width: 0.013rem;
  border-radius: 0.3rem;
  border-color: #ccc;
  box-shadow: inset 0 0 0 0.013rem #4d4d4d;
  padding: 0.625rem;
`

export const StyledLabel = styled.label`
  display: block;
  font-size: 1rem;
  padding: 0.3rem 0 0.3rem 0;
`
function Input(props: InputProps) {
  // eslint-disable-next-line react/jsx-props-no-spreading
  const { register, name, errors, type, ...rest } = props
  if (register === undefined) {
    return <></>
  }
  // eslint-disable-next-line react/jsx-props-no-spreading
  return <StyledInput {...register(name)} {...rest} />
}

Input.defaultProps = {
  type: 'text',
  errors: {},
}

export default Input
