import React from 'react'
import fetchMock, { enableFetchMocks } from 'jest-fetch-mock'
import { render, waitFor, screen } from 'test-utils'
import AdapterDateFns from '@mui/lab/AdapterDateFns'
import { LocalizationProvider } from '@mui/lab'
import GuestRegister from './index'

enableFetchMocks()

const testData = {
  person: {
    first_name: 'Test',
    last_name: 'Tester',
    mobile_phone: '+4797543910',
    email: 'test@example.org',
    fnr: '04062141242',
    passport: 'NO-123456',
  },
  role: {
    ou_name_en: 'English organizational unit name',
    ou_name_nb: 'Norsk navn organisasjonsenhet',
    name_en: 'Guest role',
    name_nb: 'Gjesterolle',
    start: '2021-08-10',
    end: '2021-08-16',
    comment: '',
  },
  meta: {
    session_type: 'invite',
  },
}

beforeEach(() => {
  fetchMock.mockIf('/api/ui/v1/invited', () =>
    Promise.resolve<any>(JSON.stringify(testData))
  )
})

test('Mobile phone number parsed and split correctly', async () => {
  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegister />
    </LocalizationProvider>
  )

  await waitFor(() => screen.queryByText(testData.person.first_name))
  await waitFor(() => screen.queryByText(testData.person.last_name))
  await waitFor(() => screen.queryByText(testData.person.email))
  await waitFor(() => screen.queryByText(testData.person.fnr))
  await waitFor(() => screen.queryByText('NO'))
  await waitFor(() => screen.queryByText('123456'))

  // There is no proper i18n loaded so the country name will be undefined, the country code should still show though
  await waitFor(() => screen.queryByText('undefined (47)'))
  await waitFor(() => screen.queryByText('97543910'))
})
