import React, { useEffect, useState } from 'react'
import { Route } from 'react-router-dom'

import FrontPage from 'routes/sponsor/frontpage'
import GuestInfo from 'routes/sponsor/guestInfo'
import GuestRoleInfo from 'routes/sponsor/guestRoleInfo'
import { FetchedGuest, Guest } from 'interfaces'

function Sponsor() {
  const [guests, setGuests] = useState<Guest[]>([])

  const getGuestsInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/guests/?format=json')
      const jsonResponse = await response.json()
      if (response.ok) {
        const roles = await jsonResponse.roles
        setGuests(
          roles.map((person: FetchedGuest) => ({
            id: person.id,
            pid: person.pid,
            name: `${person.first} ${person.last}`,
            email: person.email,
            mobile: person.mobile,
            fnr: person.fnr,
            role_nb: person.role_nb,
            role_en: person.role_en,
            max_days: person.max_days,
            start_date: new Date(Date.parse(person.start_date)),
            end_date: new Date(Date.parse(person.end_date)),
            active: person.active,
            ou_nb: person.ou_nb,
            ou_en: person.ou_en,
          }))
        )
      } else {
        setGuests([])
      }
    } catch (error) {
      setGuests([])
    }
  }

  useEffect(() => {
    getGuestsInfo()
  }, [])

  return (
    <>
      <Route path="/sponsor/guest/:pid/roles/:id">
        <GuestRoleInfo guests={guests} />
      </Route>
      <Route exact path="/sponsor/guest/:pid">
        <GuestInfo guests={guests} />
      </Route>
      <Route exact path="/sponsor">
        <FrontPage guests={guests} />
      </Route>
    </>
  )
}

export default Sponsor
