import datetime

import pytest
from django.core.management import call_command
from orgreg_client import OrgUnit, OrgUnitList

from greg.models import OrganizationalUnit


@pytest.fixture
def old_unit():
    OrganizationalUnit.objects.create(orgreg_id="4", name_nb="a", name_en="b")
    return OrganizationalUnit.objects.get(orgreg_id="4")


@pytest.fixture
def orgreg_response():
    orgreg_ous = OrgUnitList(
        __root__=[
            OrgUnit(
                ou_id=1,
                valid_from=datetime.date(year=2020, month=2, day=4),
                external_keys=[],
                name={"nob": "foo"},
            ),
            OrgUnit(
                ou_id=3,
                valid_from=datetime.date(year=2020, month=2, day=6),
                valid_to=datetime.date(year=2020, month=2, day=7),
                parent=2,
                name={"nob": "bar"},
                external_keys=[],
            ),
            OrgUnit(
                ou_id=2,
                valid_from=datetime.date(year=2020, month=2, day=5),
                parent=1,
                name={"eng": "baz"},
                external_keys=[],
            ),
        ]
    )
    return orgreg_ous


@pytest.mark.django_db
def test_command_ou_init(requests_mock, old_unit, orgreg_response):
    requests_mock.get("https://example.com/fake/ou/", text=orgreg_response.json())
    assert OrganizationalUnit.objects.all().count() == 1
    call_command("import_from_orgreg")

    # Ensure all three new units are imported
    assert OrganizationalUnit.objects.all().count() == 4

    # Ensure tree is built correctly
    assert OrganizationalUnit.objects.get(orgreg_id="3").parent.orgreg_id == "2"
    assert OrganizationalUnit.objects.get(orgreg_id="3").parent.parent.orgreg_id == "1"

    # Ensure unknown org is marked deleted
    assert OrganizationalUnit.objects.get(orgreg_id="4").deleted is True


@pytest.mark.django_db
def test_run_twice(requests_mock, orgreg_response):
    requests_mock.get("https://example.com/fake/ou/", text=orgreg_response.json())

    assert OrganizationalUnit.objects.all().count() == 0

    call_command("import_from_orgreg")
    assert OrganizationalUnit.objects.all().count() == 3

    call_command("import_from_orgreg")
    assert OrganizationalUnit.objects.all().count() == 3
